@@ -268,6 +268,24 @@ class Dic:
     """
     Locate Methods
     """
+    @classmethod
+    def locate_key(cls, dic: TyDic, key: TyKey) -> TyAny:
+        """
+        Return the value of the key reached by looping thru the
+        nested Dictionary with the keys from the key list until
+        the value is None or the last key is reached.
+        """
+        if not dic:
+            msg = "The Parameter 'dic' is None or empty"
+            raise Exception(msg)
+        if not key:
+            return dic
+        _value = dic.get(key)
+        if _value is None:
+            msg = "The Key={key} does not exist in Dictionary={dic}"
+            raise Exception(msg)
+        return _value
+
     @classmethod
     def locate(cls, dic: TyDic, keys: TyKeys) -> TyAny:
         """
