@@ -1,5 +1,6 @@
 # coding=utf-8
 from ut_dic.dic import Dic
+from ut_obj.obj import Obj
 
 from collections.abc import Callable
 from typing import Any, Dict, Union
@@ -27,7 +28,7 @@ class DoC:
         Get the cmd from arguments and keyword argument list kwargs
         and call the ex function with the given cmd.
         """
-        cmd: TnArr_Str = kwargs.get('cmd')
+        cmd: TyArr_Str = Dic.locate_key(kwargs, 'cmd')
         cls.ex(doc, cmd, kwargs)
 
     @classmethod
@@ -36,17 +37,9 @@ class DoC:
         Locate the function with the given cmd in the Dictionary of
         callables and execute the function with the keyword arguments.
         """
-        if not cmd:
-            msg = f"Command: {cmd} is not defined"
-            raise Exception(msg)
-            return
+        _a_cmd = Obj.sh_arr(cmd)
         if not doc:
-            msg = f"Function table: {doc} is not defined"
-            return
-        if not isinstance(cmd, list):
-            cmd = [cmd]
-        fnc: TnCallable = Dic.locate(doc, cmd)
-        if fnc is None:
-            msg = f"Command: {cmd} is not defined in function table: {doc}"
-            raise Exception(msg)
+            _msg = "Function table: 'doc' is not defined"
+            raise Exception(_msg)
+        fnc: TyCallable = Dic.locate(doc, _a_cmd)
         fnc(kwargs)
